# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/fi_FI/__init__.py

person_formats_fi_fi <- c(
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{last_names}}, {{first_names}}"
)

person_prefixes_fi_fi <- c(
  "Herra", "hra", "Rouva", "rva", "Tohtori", "tri", "prof.", "arkkit."
)

person_suffixes_fi_fi <- c("DI", "PhD", "MSc", "BSc")

person_first_names_fi_fi <- c(
  "Aake",
  "Aapeli",
  "Aapo",
  "Aarne",
  "Aarni",
  "Aarno",
  "Aaro",
  "Aaron",
  "Aarre",
  "Aatami",
  "Aatos",
  "Aatto",
  "Aatu",
  "Ahti",
  "Aimo",
  "Aki",
  "Aksel",
  "Akseli",
  "Aku",
  "Alarik",
  "Aleksanteri",
  "Aleksi",
  "Aleksis",
  "Ali",
  "Allan",
  "Alpo",
  "Altti",
  "Alvar",
  "Alvari",
  "Anselmi",
  "Anssi",
  "Antero",
  "Anton",
  "Antti",
  "Antton",
  "Anttoni",
  "Ari",
  "Ari-Pekka",
  "Armas",
  "Arto",
  "Arttu",
  "Arttur",
  "Artturi",
  "Arvi",
  "Arvo",
  "Asko",
  "Aslak",
  "Asser",
  "Asseri",
  "Atte",
  "Aukusti",
  "Aulis",
  "Auvo",
  "Benjam",
  "Benjamin",
  "Daniel",
  "Eeli",
  "Eelis",
  "Eemeli",
  "Eemil",
  "Eerik",
  "Eerikki",
  "Eero",
  "Eetu",
  "Eevert",
  "Eevertti",
  "Einari",
  "Eino",
  "Elias",
  "Eliel",
  "Eljas",
  "Elmeri",
  "Elmo",
  "Ensio",
  "Erkki",
  "Erno",
  "Esa",
  "Esaias",
  "Esko",
  "Hannes",
  "Hannu",
  "Harri",
  "Harry",
  "Heikki",
  "Heimo",
  "Heino",
  "Hemmo",
  "Henri",
  "Henrik",
  "Henrikki",
  "Herman",
  "Hermanni",
  "Huugo",
  "Iikka",
  "Iiro",
  "Iisak",
  "Iisakki",
  "Iivari",
  "Ilari",
  "Ilkka",
  "Ilmari",
  "Ilmo",
  "Ilpo",
  "Immanuel",
  "Into",
  "Ismo",
  "Isto",
  "Jaakko",
  "Jalmar",
  "Jalmari",
  "Jalo",
  "Jami",
  "Jani",
  "Janne",
  "Jari",
  "Jari-Pekka",
  "Jarkko",
  "Jarmo",
  "Jarno",
  "Jasper",
  "Jere",
  "Jeremias",
  "Jesse",
  "Jimi",
  "Joel",
  "Johannes",
  "Joni",
  "Jonne",
  "Joona",
  "Joonas",
  "Joonatan",
  "Jooseppi",
  "Jori",
  "Jorma",
  "Jouko",
  "Jouni",
  "Juha",
  "Juha-Matti",
  "Juha-Pekka",
  "Juhana",
  "Juhani",
  "Juho",
  "Jukka",
  "Jukka-Pekka",
  "Julius",
  "Jussi",
  "Juuso",
  "Jyri",
  "Jyrki",
  "Kaapo",
  "Kaarle",
  "Kaarlo",
  "Kai",
  "Kaino",
  "Kalervo",
  "Kaleva",
  "Kalevi",
  "Kalle",
  "Kari",
  "Karri",
  "Kasper",
  "Kasperi",
  "Kauko",
  "Kauno",
  "Keijo",
  "Kimi",
  "Kimmo",
  "Klaus",
  "Konsta",
  "Konstantin",
  "Kosti",
  "Kristian",
  "Kullervo",
  "Kustaa",
  "Kusti",
  "Ky\u00f6sti",
  "Lari",
  "Lasse",
  "Lassi",
  "Lauri",
  "Leevi",
  "Lenni",
  "Leo",
  "Luka",
  "Luukas",
  "Manu",
  "Markku",
  "Marko",
  "Markus",
  "Martti",
  "Matias",
  "Matti",
  "Mauno",
  "Maunu",
  "Mauri",
  "Miika",
  "Miikka",
  "Mika",
  "Mikael",
  "Mikko",
  "Miko",
  "Miro",
  "Miska",
  "Nestor",
  "Nestori",
  "Niilo",
  "Niklas",
  "Niko",
  "Nikolai",
  "Nuutti",
  "Oiva",
  "Olavi",
  "Oliver",
  "Olli",
  "Olli-Pekka",
  "Onni",
  "Orvo",
  "Oskar",
  "Oskari",
  "Osmo",
  "Ossi",
  "Ossian",
  "Otso",
  "Otto",
  "Paavali",
  "Paavo",
  "Panu",
  "Pasi",
  "Paul",
  "Pauli",
  "Pekka",
  "Pellervo",
  "Pentti",
  "Pertti",
  "Perttu",
  "Petri",
  "Petter",
  "Petteri",
  "Pietari",
  "Pyry",
  "P\u00e4ivi\u00f6",
  "Rafael",
  "Raimo",
  "Raine",
  "Rainer",
  "Rami",
  "Rasmus",
  "Rauli",
  "Rauni",
  "Rauno",
  "Reijo",
  "Reima",
  "Reino",
  "Riku",
  "Risto",
  "Roni",
  "Sakari",
  "Saku",
  "Salomon",
  "Sami",
  "Sampo",
  "Sampsa",
  "Samu",
  "Samuel",
  "Samuli",
  "Santeri",
  "Santtu",
  "Sauli",
  "Sebastian",
  "Seppo",
  "Severi",
  "Simo",
  "Soini",
  "Sulevi",
  "Sulo",
  "Taavetti",
  "Taavi",
  "Taisto",
  "Taito",
  "Taneli",
  "Tapani",
  "Tapio",
  "Tarmo",
  "Tatu",
  "Tauno",
  "Teemu",
  "Teijo",
  "Tenho",
  "Teppo",
  "Terho",
  "Tero",
  "Teuvo",
  "Timo",
  "Tino",
  "Toimi",
  "Toivo",
  "Tomi",
  "Tommi",
  "Toni",
  "Topi",
  "Topias",
  "Torsti",
  "Touko",
  "Tuomas",
  "Tuomo",
  "Tuukka",
  "Tuure",
  "Ukko",
  "Uljas",
  "Untamo",
  "Unto",
  "Uolevi",
  "Urho",
  "Urpo",
  "Usko",
  "Uuno",
  "Valde",
  "Valdemar",
  "Valentin",
  "Valto",
  "Valtteri",
  "Waltteri",
  "Veeti",
  "Veijo",
  "Veikka",
  "Veikko",
  "Veli",
  "Veli-Matti",
  "Veli-Pekka",
  "Verner",
  "Verneri",
  "Vesa",
  "Vieno",
  "Vilhelmi",
  "Vilho",
  "Vili",
  "Viljam",
  "Viljami",
  "Viljo",
  "Ville",
  "Voitto",
  "V\u00e4in\u00e4m\u00f6",
  "V\u00e4in\u00f6",
  "Ylermi",
  "Yrj\u00f6",
  "Aada",
  "Aallotar",
  "Aija",
  "Aila",
  "Aili",
  "Aina",
  "Aini",
  "Aino",
  "Aira",
  "Airi",
  "Aleksandra",
  "Aliina",
  "Aliisa",
  "Alina",
  "Alisa",
  "Alli",
  "Alma",
  "Amalia",
  "Amanda",
  "Anastasia",
  "Anelma",
  "Anette",
  "Anita",
  "Anitta",
  "Anja",
  "Anna",
  "Anna-Kaisa",
  "Anna-Leena",
  "Anna-Liisa",
  "Anna-Maija",
  "Anna-Mari",
  "Anna-Maria",
  "Anne",
  "Anne-Mari",
  "Anne-Maria",
  "Annele",
  "Anneli",
  "Anni",
  "Anniina",
  "Annika",
  "Annikki",
  "Annukka",
  "Anu",
  "Arja",
  "Armi",
  "Asta",
  "Auli",
  "Aulikki",
  "Aune",
  "Aura",
  "Aurora",
  "Bertta",
  "Eedit",
  "Eelin",
  "Eerika",
  "Eeva",
  "Eeva-Liisa",
  "Eevi",
  "Eija",
  "Eila",
  "Eine",
  "Eini",
  "Eira",
  "Elena",
  "Eliina",
  "Eliisa",
  "Eliisabet",
  "Elina",
  "Elisa",
  "Elisabet",
  "Elise",
  "Ella",
  "Ellen",
  "Elli",
  "Elma",
  "Elna",
  "Elsa",
  "Else",
  "Elsi",
  "Elvi",
  "Elviira",
  "Emilia",
  "Emma",
  "Emmi",
  "Enni",
  "Eriika",
  "Erja",
  "Essi",
  "Ester",
  "Esteri",
  "Eveliina",
  "Fanni",
  "Hanna",
  "Hanna-Leena",
  "Hanna-Mari",
  "Hanne",
  "Hannele",
  "Heidi",
  "Heini",
  "Heleena",
  "Helena",
  "Heli",
  "Helin\u00e4",
  "Helj\u00e4",
  "Helka",
  "Hellevi",
  "Helli",
  "Hellin",
  "Hell\u00e4",
  "Helmi",
  "Helmiina",
  "Helvi",
  "Hely",
  "Henna",
  "Henrietta",
  "Henriikka",
  "Hertta",
  "Heta",
  "Hilda",
  "Hilja",
  "Hilkka",
  "Hilla",
  "Hillevi",
  "Hilma",
  "Iida",
  "Iina",
  "Iines",
  "Iiris",
  "Ilma",
  "Ilmi",
  "Ilona",
  "Ilta",
  "Impi",
  "Inari",
  "Inka",
  "Inkeri",
  "Ira",
  "Irene",
  "Irina",
  "Iris",
  "Irja",
  "Irma",
  "Irmeli",
  "Isabella",
  "Jaana",
  "Jade",
  "Janette",
  "Janika",
  "Janina",
  "Janita",
  "Janna",
  "Jasmiina",
  "Jasmin",
  "Jemina",
  "Jenna",
  "Jenni",
  "Joanna",
  "Johanna",
  "Jonna",
  "Josefiina",
  "Julia",
  "Justiina",
  "Jutta",
  "Juulia",
  "Kaarin",
  "Kaarina",
  "Kaija",
  "Kaino",
  "Kaisa",
  "Kaisu",
  "Kanerva",
  "Karita",
  "Karoliina",
  "Katariina",
  "Kati",
  "Katja",
  "Katri",
  "Katriina",
  "Kerttu",
  "Kiia",
  "Kirsi",
  "Kirsi-Marja",
  "Kirsti",
  "Kreeta",
  "Krista",
  "Kristiina",
  "Kustaava",
  "Kyllikki",
  "Lahja",
  "Laila",
  "Laimi",
  "Laina",
  "Laura",
  "Lea",
  "Leea",
  "Leena",
  "Leila",
  "Lemmikki",
  "Lemmitty",
  "Lempi",
  "Liisa",
  "Liisi",
  "Lilja",
  "Lilli",
  "Linda",
  "Linnea",
  "Lotta",
  "Loviisa",
  "Lumi",
  "Lyydi",
  "Lyydia",
  "Lyyli",
  "Maaret",
  "Maaria",
  "Maarit",
  "Maija",
  "Maija-Leena",
  "Maija-Liisa",
  "Maiju",
  "Maila",
  "Maire",
  "Margareeta",
  "Margareetta",
  "Mari",
  "Maria",
  "Marianna",
  "Marianne",
  "Mariia",
  "Mariitta",
  "Marika",
  "Marita",
  "Maritta",
  "Marja",
  "Marja-Leena",
  "Marja-Liisa",
  "Marja-Riitta",
  "Marja-Terttu",
  "Marjaana",
  "Marjatta",
  "Marjo",
  "Marjo-Riitta",
  "Marjukka",
  "Marjut",
  "Marketta",
  "Marleena",
  "Martta",
  "Matilda",
  "Matleena",
  "Meeri",
  "Meri",
  "Merja",
  "Mervi",
  "Miia",
  "Miina",
  "Mikaela",
  "Milja",
  "Milka",
  "Milla",
  "Mimosa",
  "Minea",
  "Minja",
  "Minna",
  "Minttu",
  "Mira",
  "Mirja",
  "Mirjam",
  "Mirjami",
  "Mirka",
  "Mirva",
  "Moona",
  "Naima",
  "Natalia",
  "Nea",
  "Neea",
  "Nella",
  "Nelli",
  "Netta",
  "Niina",
  "Noora",
  "Oili",
  "Olivia",
  "Onerva",
  "Oona",
  "Orvokki",
  "Outi",
  "Paula",
  "Pauliina",
  "Peppi",
  "Petra",
  "Pihla",
  "Piia",
  "Pilvi",
  "Pinja",
  "Pirita",
  "Piritta",
  "Pirjo",
  "Pirkko",
  "Pirkko-Liisa",
  "P\u00e4ivi",
  "P\u00e4ivikki",
  "Raakel",
  "Raija",
  "Raila",
  "Raili",
  "Raisa",
  "Rauha",
  "Rauni",
  "Rebekka",
  "Reeta",
  "Reetta",
  "Reija",
  "Riikka",
  "Riina",
  "Riitta",
  "Riitta-Liisa",
  "Ritva",
  "Ronja",
  "Roosa",
  "Saana",
  "Saara",
  "Saija",
  "Saila",
  "Saima",
  "Saimi",
  "Saini",
  "Salla",
  "Salli",
  "Salme",
  "Sanelma",
  "Sanna",
  "Sanni",
  "Sara",
  "Sari",
  "Sarita",
  "Satu",
  "Seija",
  "Selma",
  "Senja",
  "Senni",
  "Siiri",
  "Silja",
  "Sini",
  "Sinikka",
  "Sirkka",
  "Sirkka-Liisa",
  "Sirkku",
  "Sirpa",
  "Sisko",
  "Sivi\u00e4",
  "Sofia",
  "Sohvi",
  "Soile",
  "Soili",
  "Soilikki",
  "Sointu",
  "Sonja",
  "Stiina",
  "Suoma",
  "Susan",
  "Susanna",
  "Susanne",
  "Suvi",
  "Sylvi",
  "Sylvia",
  "S\u00e4de",
  "Taija",
  "Taimi",
  "Taina",
  "Talvikki",
  "Tanja",
  "Tarja",
  "Taru",
  "Tea",
  "Teija",
  "Tekla",
  "Tellervo",
  "Teresa",
  "Terhi",
  "Terhikki",
  "Terttu",
  "Tiia",
  "Tiina",
  "Tilda",
  "Titta",
  "Toini",
  "Tuija",
  "Tuire",
  "Tuovi",
  "Tuuli",
  "Tuulia",
  "Tuulikki",
  "Tytti",
  "Tyyne",
  "Tyyni",
  "Ulla",
  "Ulla-Maija",
  "Unelma",
  "Ursula",
  "Valma",
  "Valpuri",
  "Vappu",
  "Varpu",
  "Veera",
  "Vellamo",
  "Venla",
  "Vieno",
  "Viivi",
  "Vilhelmiina",
  "Wilhelmiina",
  "Vilja",
  "Vilma",
  "Wilma",
  "Viola",
  "Virpi",
  "Virva",
  "Virve",
  "Vuokko"
)

person_last_names_fi_fi <- c(
  "Aalto",
  "Aaltonen",
  "Aarnio",
  "Ahde",
  "Aho",
  "Ahopalo",
  "Ahokas",
  "Ahokangas",
  "Ahola",
  "Ahonen",
  "Ahti",
  "Ahtisaari",
  "Alanen",
  "Alasalmi",
  "Alho",
  "Annala",
  "Anttila",
  "Anttonen",
  "Araj\u00e4rvi",
  "Aro",
  "Aromaa",
  "Asikainen",
  "Askola",
  "Astala",
  "Asunmaa",
  "Aura",
  "Autio",
  "Auvinen",
  "Eerik\u00e4inen",
  "Eerola",
  "Eini\u00f6",
  "Ekola",
  "Elo",
  "Elomaa",
  "Eloranta",
  "Elsil\u00e4",
  "Ernamo",
  "Erola",
  "Eronen",
  "Eskelinen",
  "Eskola",
  "Haanp\u00e4\u00e4",
  "Haapakoski",
  "Haapasalo",
  "Haataja",
  "Hakala",
  "Hannula",
  "Harju",
  "Harjula",
  "Hartikainen",
  "Hautala",
  "Heikkil\u00e4",
  "Heikkinen",
  "Heinonen",
  "Heiskanen",
  "Helminen",
  "Hietanen",
  "Hiltunen",
  "Hinkkanen",
  "Hintikka",
  "Hirsj\u00e4rvi",
  "Hirvel\u00e4",
  "Hirvonen",
  "Holappa",
  "Hujanen",
  "Huotari",
  "Huovinen",
  "Huttunen",
  "Huusko",
  "Huuskonen",
  "Hynninen",
  "Hyttinen",
  "H\u00e4kkinen",
  "H\u00e4k\u00e4mies",
  "H\u00e4m\u00e4l\u00e4inen",
  "H\u00e4nninen",
  "Ihalainen",
  "Iham\u00e4ki",
  "Iivonen",
  "Ij\u00e4s",
  "Ikola",
  "Ikonen",
  "Ik\u00e4heimo",
  "Ilmola",
  "Ilmonen",
  "Ilvonen",
  "Immonen",
  "Inkinen",
  "Innanen",
  "Isokangas",
  "Isokallio",
  "Isokoski",
  "Isomets\u00e4",
  "Isom\u00e4ki",
  "Isotalo",
  "Issakainen",
  "Itkonen",
  "It\u00e4l\u00e4",
  "Jaakkola",
  "Jaakonsaari",
  "Jaatinen",
  "Jalava",
  "Jalkanen",
  "Jalonen",
  "Jantunen",
  "Jarva",
  "Jokela",
  "Jokelainen",
  "Jokinen",
  "Juhola",
  "Jukarainen",
  "Jukola",
  "Julkunen",
  "Juntunen",
  "Jussila",
  "Jutila",
  "Juva",
  "Juvonen",
  "Jylh\u00e4",
  "J\u00e4ntti",
  "J\u00e4rvi",
  "J\u00e4rvilehto",
  "J\u00e4rvinen",
  "J\u00e4\u00e4skel\u00e4inen",
  "Kainulainen",
  "Kallio",
  "Kalliokoski",
  "Kangas",
  "Karhu",
  "Karjalainen",
  "Karonen",
  "Karppanen",
  "Karppinen",
  "Kataisto",
  "Kataja",
  "Kemppainen",
  "Keskinen",
  "Keto",
  "Ketola",
  "Kettunen",
  "Kinnunen",
  "Kivel\u00e4",
  "Kiviluoto",
  "Kivinen",
  "Kivist\u00f6",
  "Koistinen",
  "Koivula",
  "Kokkonen",
  "Korhonen",
  "Korpela",
  "Koskinen",
  "Kosonen",
  "Krouvi",
  "Kulmala",
  "Kunnas",
  "Kuosmanen",
  "Kuparinen",
  "Kurkela",
  "Kurkinen",
  "Kuusela",
  "Kuusisto",
  "Laaksonen",
  "Laatikainen",
  "Lahtela",
  "Lahti",
  "Lahtinen",
  "Laiho",
  "Laine",
  "Laitinen",
  "Lamminen",
  "Lampinen",
  "Lankinen",
  "Lappalainen",
  "Larivaara",
  "Lassila",
  "Latvanen",
  "Laukkanen",
  "Laurila",
  "Lauronen",
  "Lehtinen",
  "Lehto",
  "Lehtonen",
  "Leino",
  "Leinonen",
  "Lepist\u00f6",
  "Lepp\u00e4l\u00e4",
  "Lepp\u00e4nen",
  "Leskinen",
  "Lesonen",
  "Liikanen",
  "Lilja",
  "Linna",
  "Lipponen",
  "Litmanen",
  "Liukkonen",
  "Loponen",
  "Luhtanen",
  "Lumme",
  "Luostarinen",
  "Makkonen",
  "Manninen",
  "Markku",
  "Martikainen",
  "Matikainen",
  "Matinsalo",
  "Mattila",
  "Meriluoto",
  "Miettunen",
  "Mieto",
  "Mikkola",
  "Moilanen",
  "Mustonen",
  "Muukkonen",
  "Myllyl\u00e4",
  "Myllyniemi",
  "M\u00e4enp\u00e4\u00e4",
  "M\u00e4kel\u00e4",
  "M\u00e4ki",
  "M\u00e4kil\u00e4",
  "M\u00e4kinen",
  "M\u00e4ntt\u00e4ri",
  "M\u00e4nty",
  "M\u00e4\u00e4tt\u00e4",
  "Naaraj\u00e4rvi",
  "Narinen",
  "Nenonen",
  "Neuvonen",
  "Nevala",
  "Nevalainen",
  "Niemel\u00e4",
  "Niemi",
  "Nieminen",
  "Niinisalo",
  "Niinist\u00f6",
  "Niiranen",
  "Nikkinen",
  "Nikkola",
  "Nikkonen",
  "Nikula",
  "Niskala",
  "Nissinen",
  "Nousiainen",
  "Nummi",
  "Numminen",
  "Nurmela",
  "Nurmi",
  "Nurminen",
  "Nuutinen",
  "Nyk\u00e4nen",
  "N\u00e4rhi",
  "Oikarinen",
  "Oittinen",
  "Ojakangas",
  "Ojala",
  "Ojalehto",
  "Ojanen",
  "Oksanen",
  "Ollikainen",
  "Ollila",
  "Onnela",
  "Oranen",
  "Otila",
  "Outila",
  "Outinen",
  "Ovaska",
  "Paananen",
  "Paasio",
  "Pajari",
  "Pale",
  "Pakarinen",
  "Parras",
  "Parviainen",
  "Pasanen",
  "Pekkanen",
  "Pekkala",
  "Pelkonen",
  "Peltola",
  "Peltonen",
  "Peltoniemi",
  "Peltosaari",
  "Pennanen",
  "Pesonen",
  "Pes\u00e4l\u00e4",
  "Pet\u00e4j\u00e4",
  "Pirhonen",
  "Pirinen",
  "Pitk\u00e4nen",
  "Pohjola",
  "Pohjonen",
  "Pokka",
  "Porkka",
  "Poso",
  "Poutanen",
  "Puikkonen",
  "Pulkkinen",
  "Purho",
  "Pyysalo",
  "P\u00e4\u00e4talo",
  "Rahikainen",
  "Rahkamo",
  "Rahnasto",
  "Rajala",
  "Rannisto",
  "Rantala",
  "Rantanen",
  "Rauhala",
  "Rautakorpi",
  "Rautanen",
  "Rautavaara",
  "Rautiainen",
  "Rautio",
  "Reinikainen",
  "Rekunen",
  "Repo",
  "Repomem",
  "Riihel\u00e4",
  "Riihij\u00e4rvi",
  "Riikonen",
  "Rinne",
  "Rintala",
  "Rissanen",
  "Ritala",
  "Roimola",
  "Roivas",
  "Ronni",
  "Ruohonen",
  "Ruutu",
  "Rytt\u00e4ri",
  "R\u00e4ikk\u00f6nen",
  "R\u00e4is\u00e4nen",
  "R\u00e4ty",
  "Saarela",
  "Saari",
  "Saarikoski",
  "Saario",
  "Saarinen",
  "Saikkonen",
  "Sainio",
  "Saisio",
  "Saksala",
  "Salli",
  "Sallinen",
  "Salmi",
  "Salminen",
  "Salo",
  "Salonen",
  "Savolainen",
  "Sepp\u00e4l\u00e4",
  "Sepp\u00e4nen",
  "Set\u00e4l\u00e4",
  "Sillanp\u00e4\u00e4",
  "Sinisalo",
  "Sipil\u00e4",
  "Sipinen",
  "Sirki\u00e4",
  "Sirvi\u00f6",
  "Soikkeli",
  "Soinio",
  "Sormunen",
  "Suhonen",
  "Sulkanen",
  "Suntila",
  "Suominen",
  "Supinen",
  "Takala",
  "Tammisto",
  "Tamminen",
  "Tanskanen",
  "Taipale",
  "Tarkka",
  "Tenhunen",
  "Tiainen",
  "Tiihonen",
  "Tiilikainen",
  "Tikkanen",
  "Timonen",
  "Tirkkonen",
  "Toivonen",
  "Tuomi",
  "Tuominen",
  "Tuomioja",
  "Tuomola",
  "Turunen",
  "Tuuri",
  "Ukkola",
  "Ulmanen",
  "Uosukainen",
  "Uotila",
  "Uotinen",
  "Uronen",
  "Utriainen",
  "Utrio",
  "Uusitalo",
  "Vainikainen",
  "Vainio",
  "Vanhala",
  "Varala",
  "Varis",
  "Varvikko",
  "Vatanen",
  "Veintie",
  "Ven\u00e4l\u00e4inen",
  "Viitala",
  "Viitanen",
  "Viljanen",
  "Vinni",
  "Virolainen",
  "Virtanen",
  "Vitikka",
  "Voutilainen",
  "Vuolle",
  "Vuorela",
  "Vuorinen",
  "Vuoristo",
  "V\u00e4lkkynen",
  "V\u00e4\u00e4n\u00e4nen",
  "V\u00e4\u00e4t\u00e4inen",
  "Ykspet\u00e4j\u00e4",
  "Ylikangas",
  "Ylikoski",
  "Ylim\u00e4ki",
  "Ylinen",
  "Yliniemi",
  "Ylioja",
  "Ylisuvanto",
  "Ylitalo",
  "Yl\u00e4m\u00e4ki",
  "Yl\u00e4nne",
  "Yl\u00e4talo",
  "Yl\u00f6nen",
  "Yl\u00f6stalo",
  "Yrj\u00e4l\u00e4",
  "Yrj\u00e4n\u00e4",
  "Yrj\u00e4n\u00e4inen",
  "Yrj\u00f6l\u00e4",
  "Yrj\u00f6nen"
)

person_fi_fi <- list(
  first_names = person_first_names_fi_fi,
  last_names = person_last_names_fi_fi,
  prefixes = person_prefixes_fi_fi,
  suffixes = person_prefixes_fi_fi
)
